nxp-pac

Crates

git

Versions

mcxa577

Flavors

Prescale

Enum Prescale 

#[repr(u8)]
pub enum Prescale {
Show 16 variants PRESCALE0000 = 0, PRESCALE0001 = 1, PRESCALE0010 = 2, PRESCALE0011 = 3, PRESCALE0100 = 4, PRESCALE0101 = 5, PRESCALE0110 = 6, PRESCALE0111 = 7, PRESCALE1000 = 8, PRESCALE1001 = 9, PRESCALE1010 = 10, PRESCALE1011 = 11, PRESCALE1100 = 12, PRESCALE1101 = 13, PRESCALE1110 = 14, PRESCALE1111 = 15,
}

Variants



PRESCALE0000 = 0

Prescaler divides the prescaler clock by 2; glitch filter does not support this configuration



PRESCALE0001 = 1

Prescaler divides the prescaler clock by 4; glitch filter recognizes change on input pin after two rising clock edges



PRESCALE0010 = 2

Prescaler divides the prescaler clock by 8; glitch filter recognizes change on input pin after four rising clock edges



PRESCALE0011 = 3

Prescaler divides the prescaler clock by 16; glitch filter recognizes change on input pin after eight rising clock edges



PRESCALE0100 = 4

Prescaler divides the prescaler clock by 32; glitch filter recognizes change on input pin after 16 rising clock edges



PRESCALE0101 = 5

Prescaler divides the prescaler clock by 64; glitch filter recognizes change on input pin after 32 rising clock edges



PRESCALE0110 = 6

Prescaler divides the prescaler clock by 128; glitch filter recognizes change on input pin after 64 rising clock edges



PRESCALE0111 = 7

Prescaler divides the prescaler clock by 256; glitch filter recognizes change on input pin after 128 rising clock edges



PRESCALE1000 = 8

Prescaler divides the prescaler clock by 512; glitch filter recognizes change on input pin after 256 rising clock edges



PRESCALE1001 = 9

Prescaler divides the prescaler clock by 1024; glitch filter recognizes change on input pin after 512 rising clock edges



PRESCALE1010 = 10

Prescaler divides the prescaler clock by 2048; glitch filter recognizes change on input pin after 1024 rising clock edges



PRESCALE1011 = 11

Prescaler divides the prescaler clock by 4096; glitch filter recognizes change on input pin after 2048 rising clock edges



PRESCALE1100 = 12

Prescaler divides the prescaler clock by 8192; glitch filter recognizes change on input pin after 4096 rising clock edges



PRESCALE1101 = 13

Prescaler divides the prescaler clock by 16,384; glitch filter recognizes change on input pin after 8192 rising clock edges



PRESCALE1110 = 14

Prescaler divides the prescaler clock by 32,768; glitch filter recognizes change on input pin after 16,384 rising clock edges



PRESCALE1111 = 15

Prescaler divides the prescaler clock by 65,536; glitch filter recognizes change on input pin after 32,768 rising clock edges

Implementations

Source

impl Prescale

pub const fn from_bits(val: u8) -> Prescale

pub const fn to_bits(self) -> u8